@@ -39,6 +39,12 @@ class Discard(Action):
     cards: list[Card]
 
 
+@dataclass
+class DetailedDiscard(Discard):
+    '''A class to keep track of all details of one player's discard action'''
+    kept: list[Card]
+
+
 @dataclass
 class Play(Action):
     '''A class to keep track of one play in a trick'''
